@@ -24,14 +24,11 @@
  */
 
 #include "config.h"
-
-#include <telepathy-glib/telepathy-glib.h>
+#include "mcp-account-manager-goa.h"
 
 #define GOA_API_IS_SUBJECT_TO_CHANGE /* awesome! */
 #include <goa/goa.h>
 
-#include "mcp-account-manager-goa.h"
-
 #define DEBUG g_debug
 #define GET_PRIVATE(self) (((McpAccountManagerGoa *) self)->priv)
 #define DECLARE_GASYNC_CALLBACK(name) \
@@ -197,9 +194,6 @@ object_chat_changed_cb (GoaObject *object,
   char *name = get_tp_account_name (account);
   gboolean enabled;
 
-  if (name == NULL)
-    return;
-
   enabled = (goa_object_peek_chat (object) != NULL);
 
   DEBUG ("%s %s", name, enabled ? "enabled" : "disabled");
@@ -295,9 +289,6 @@ _account_removed_cb (GoaClient *client,
   GoaAccount *account = goa_object_peek_account (object);
   char *name = get_tp_account_name (account);
 
-  if (name == NULL)
-    return;
-
   if (self->priv->ready)
     g_signal_emit_by_name (self, "deleted", name);
 
