@@ -22,14 +22,14 @@
  */
 
 #include "config.h"
+#include "empathy-account-chooser.h"
 
 #include <glib/gi18n-lib.h>
 
 #include "empathy-ui-utils.h"
-#include "empathy-account-chooser.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 /**
  * SECTION:empathy-account-chooser
