@@ -21,8 +21,7 @@
 #ifndef __EMPATHY_ACCOUNT_WIDGET_SIP_H__
 #define __EMPATHY_ACCOUNT_WIDGET_SIP_H__
 
-#include <gtk/gtk.h>
-#include <libempathy-gtk/empathy-account-widget.h>
+#include "empathy-account-widget.h"
 
 G_BEGIN_DECLS
 
