@@ -22,13 +22,13 @@
  */
 
 #include "config.h"
+#include "empathy-avatar-image.h"
 
 #include <glib/gi18n-lib.h>
 #include <gdk/gdkx.h>
 
-#include <libempathy/empathy-utils.h>
-#include "empathy-avatar-image.h"
 #include "empathy-ui-utils.h"
+#include "empathy-utils.h"
 
 /**
  * SECTION:empathy-avatar-image
