@@ -22,15 +22,15 @@
  */
 
 #include "config.h"
+#include "empathy-geometry.h"
 
 #include <sys/stat.h>
 
-#include "libempathy/empathy-utils.h"
-#include "empathy-geometry.h"
 #include "empathy-ui-utils.h"
+#include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 #define GEOMETRY_DIR_CREATE_MODE  (S_IRUSR | S_IWUSR | S_IXUSR)
 #define GEOMETRY_FILE_CREATE_MODE (S_IRUSR | S_IWUSR)
