@@ -24,11 +24,10 @@
  */
 
 #include "config.h"
-
 #include "empathy-individual-store-manager.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_CONTACT
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 struct _EmpathyIndividualStoreManagerPriv
 {
