@@ -23,12 +23,10 @@
 #ifndef __EMPATHY_PROTOCOL_CHOOSER_H__
 #define __EMPATHY_PROTOCOL_CHOOSER_H__
 
-#include <glib-object.h>
 #include <gtk/gtk.h>
-
 #include <telepathy-glib/telepathy-glib.h>
 
-#include <libempathy/empathy-account-settings.h>
+#include "empathy-account-settings.h"
 
 G_BEGIN_DECLS
 
