@@ -20,22 +20,21 @@
  */
 
 #include "config.h"
+#include "empathy-theme-adium.h"
 
 #include <glib/gi18n-lib.h>
 
-#include <libempathy/empathy-gsettings.h>
-#include <libempathy/empathy-time.h>
-#include <libempathy/empathy-utils.h>
-
-#include "empathy-theme-adium.h"
-#include "empathy-smiley-manager.h"
-#include "empathy-ui-utils.h"
-#include "empathy-plist.h"
+#include "empathy-gsettings.h"
 #include "empathy-images.h"
+#include "empathy-plist.h"
+#include "empathy-smiley-manager.h"
+#include "empathy-time.h"
+#include "empathy-ui-utils.h"
+#include "empathy-utils.h"
 #include "empathy-webkit-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_CHAT
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 #define BORING_DPI_DEFAULT 96
 
