@@ -19,6 +19,7 @@
  */
 
 #include "config.h"
+#include "empathy-audio-src.h"
 
 #ifdef HAVE_GST1
 #include <gst/audio/streamvolume.h>
@@ -26,14 +27,12 @@
 #include <gst/interfaces/streamvolume.h>
 #endif
 
-#include <libempathy/empathy-utils.h>
 #include "empathy-audio-utils.h"
-
-#include "empathy-audio-src.h"
 #include "empathy-mic-monitor.h"
+#include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_VOIP
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 G_DEFINE_TYPE(EmpathyGstAudioSrc, empathy_audio_src, GST_TYPE_BIN)
 
