@@ -23,7 +23,6 @@
 #include "config.h"
 
 #include <glib/gi18n.h>
-
 #include <clutter-gtk/clutter-gtk.h>
 #include <clutter-gst/clutter-gst.h>
 
@@ -31,13 +30,12 @@
 #include <X11/Xlib.h>
 #endif
 
-#include <libempathy-gtk/empathy-ui-utils.h>
-
-#include "empathy-call-window.h"
 #include "empathy-call-factory.h"
+#include "empathy-call-window.h"
+#include "empathy-ui-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_VOIP
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 /* Exit after $TIMEOUT seconds if not displaying any call window */
 #define TIMEOUT 60
