@@ -22,24 +22,22 @@
  */
 
 #include "config.h"
-
 #include "empathy-sanity-cleaning.h"
 
-#include <libempathy/empathy-gsettings.h>
-
-#include <libempathy-gtk/empathy-theme-manager.h>
-
 #ifdef HAVE_UOA
-#include <libempathy/empathy-pkg-kit.h>
-#include <libempathy/empathy-uoa-utils.h>
-
 #include <libaccounts-glib/ag-account-service.h>
 #include <libaccounts-glib/ag-manager.h>
 #include <libaccounts-glib/ag-service.h>
+
+#include "empathy-pkg-kit.h"
+#include "empathy-uoa-utils.h"
 #endif
 
+#include "empathy-gsettings.h"
+#include "empathy-theme-manager.h"
+
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 /*
  * This number has to be increased each time a new task is added or modified.
